local MinBuild, MaxBuild, Build = 40000, 0, select(4, GetBuildInfo())
if Build < MinBuild or ( MaxBuild > 0 and Build > MaxBuild ) then return end
local AddonName, AddonTable = ...
local L = AddonTable.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local z = {}
AddonTable.Castable = {}
AddonTable.VehicleCastable = {}
AddonTable.ItemCastable = {}

-- SpellFlash API: http://wow.curseforge.com/addons/spellflash/pages/api/
-- x.Enemy, x.ActiveEnemy, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff


-- Example function:
AddonTable.Castable["English_Spell_Name"] = function()
	wipe(z)
	z.SpellID = GlobalSpellID--[[English_Spell_Name]]   --this is for defining the correct name of the spell
	z.DebuffSlotNeeded = 1   --use this if you want to make sure that a debuff slot is free on the target so that you do not replace other debuffs
	z.Debuff = z.SpellID   --place debuff name or table of names here if the spell has a debuff that may only be on a target once in total from everyone and has a cooldown shorter than the debuff duration
	z.MyDebuff = z.SpellID   --place debuff name or table of names here if the spell has a debuff that may be on the target multiple times by many people and has a cooldown shorter than the debuff duration
	z.Buff = z.SpellID   --place buff name or table of names here if the spell has a buff that may only be on yourself once in total from everyone and has a cooldown shorter than the buff duration
	z.MyBuff = z.SpellID   --place buff name or table of names here if the spell has a buff that may be on the target multiple times by many people and has a cooldown shorter than the buff duration
	z.BuffUnit = "player"   --you will need to use this if the buff or debuff is not applied to your target
	z.Stack = 2   --use this if the buff or debuff requires more than one application
	z.EarlyRefresh = 5   --use this to indicate the buff or debuff early for a desired number of seconds
	z.CastTime = s.CastTime(z.SpellID)   --use this only if you want to replace the spell cast time used for early indication of a buff or debuff
	z.EnemyTargetNeeded = 1   --use this if the spell should have an enemy targeted
	z.TargetThatUsesManaNeeded = 1   --use this if the spell is only useful on a target that uses mana such as mana draining spells
	z.NoRangeCheck = 1   --use this to disable range detection if the spell has a limited range but the detection in this function is not working correctly for the particular spell
	z.NotIfActive = 1   --use this if the spell may be toggled on such as auto attack or on next swing spells, or to disable when casting or channeling, or if the spell has a cooldown
	z.NotWhileMoving = 1   --use this if the spell is not able to be cast while moving
	z.NoPowerCheck = 1   --use this to disable the power checking in this function
	z.EvenIfNotUsable = 1   --use this to disable the usability checking in this function and may be used if currently in the process of completing a prerequisite that will make the spell usable
	z.Unit = "target"   --this should not be used unless the spell is not to be cast on the target
	z.Interrupt = 1   --use this if the target should be casting or channeling an interruptible ability
	return s.CheckIfSpellCastable(z)
end

-- Example function:
AddonTable.ItemCastable["English_Item_Name"] = function()
	wipe(z)
	z.ItemID = ItemID--[[English_Item_Name]]   --this is for defining the correct name of the item
	z.DebuffSlotNeeded = 1   --use this if you want to make sure that a debuff slot is free on the target so that you do not replace other debuffs
	z.Debuff = GlobalSpellID--[[English_Spell_Name]]   --place debuff name or table of names here if the item has a debuff that may only be on a target once in total from everyone and has a cooldown shorter than the debuff duration
	z.MyDebuff = GlobalSpellID--[[English_Spell_Name]]   --place debuff name or table of names here if the item has a debuff that may be on the target multiple times by many people and has a cooldown shorter than the debuff duration
	z.Buff = GlobalSpellID--[[English_Spell_Name]]   --place buff name or table of names here if the item has a buff that may only be on yourself once in total from everyone and has a cooldown shorter than the buff duration
	z.MyBuff = GlobalSpellID--[[English_Spell_Name]]   --place buff name or table of names here if the item has a buff that may be on the target multiple times by many people and has a cooldown shorter than the buff duration
	z.BuffUnit = "player"   --you will need to use this if the buff or debuff is not applied to your target
	z.Stack = 2   --use this if the buff or debuff requires more than one application
	z.EarlyRefresh = 5   --use this to indicate the buff or debuff early for a desired number of seconds
	z.CastTime = 0   --use this if the item has a cast time for indication of a buff or debuff early
	z.EnemyTargetNeeded = 1   --use this if the item should have an enemy targeted
	z.TargetThatUsesManaNeeded = 1   --use this if the item is only useful on a target that uses mana such as mana draining items
	z.NoRangeCheck = 1   --use this to disable range detection if the item has a limited range but the detection in this function is not working correctly for the particular item
	z.NoEquipCheck = 1   --use this to disable equippable detection if the item can be equipped but does not need to be
	z.NotIfActive = 1   --use this if the item may be toggled on such as auto attack or on next swing spells, or to disable when casting or channeling, or if the item has a cooldown
	z.NotWhileMoving = 1   --use this if the item is not able to be used while moving
	z.NoPowerCheck = 1   --use this to disable the power checking in this function
	z.EvenIfNotUsable = 1   --use this to disable the usability checking in this function and may be used if currently in the process of completing a prerequisite that will make the item usable
	z.Unit = "target"   --this should not be used unless the item is not to be cast on the target
	z.Interrupt = 1   --use this if the target should be casting or channeling an interruptible ability
	return s.CheckIfItemCastable(z)
end

-- Example function:
AddonTable.VehicleCastable["English_Spell_Name"] = function()
	wipe(z)
	z.SpellID = GlobalSpellID--[[English_Spell_Name]]   --this is for defining the correct name of the spell
	z.DebuffSlotNeeded = 1   --use this if you want to make sure that a debuff slot is free on the target so that you do not replace other debuffs
	z.Debuff = z.SpellID   --place debuff name or table of names here if the spell has a debuff that may only be on a target once in total from everyone and has a cooldown shorter than the debuff duration
	z.MyDebuff = z.SpellID   --place debuff name or table of names here if the spell has a debuff that may be on the target multiple times by many people and has a cooldown shorter than the debuff duration
	z.Buff = z.SpellID   --place buff name or table of names here if the spell has a buff that may only be on yourself once in total from everyone and has a cooldown shorter than the buff duration
	z.MyBuff = z.SpellID   --place buff name or table of names here if the spell has a buff that may be on the target multiple times by many people and has a cooldown shorter than the buff duration
	z.BuffUnit = "vehicle"   --you will need to use this if the buff or debuff is not applied to your target
	z.Stack = 2   --use this if the buff or debuff requires more than one application
	z.EarlyRefresh = 5   --use this to indicate the buff or debuff early for a desired number of seconds
	z.CastTime = 0   --use this if the spell has a cast time for indication of a buff or debuff early
	z.EnemyTargetNeeded = 1   --use this if the spell should have an enemy targeted
	z.TargetThatUsesManaNeeded = 1   --use this if the spell is only useful on a target that uses mana such as mana draining spells
	z.NoRangeCheck = 1   --use this to disable range detection if the spell has a limited range but the detection in this function is not working correctly for the particular spell
	z.NotIfActive = 1   --use this if the spell may be toggled on such as auto attack or on next swing spells, or to disable when casting or channeling, or if the spell has a cooldown
	z.NotWhileMoving = 1   --use this if the spell is not able to be cast while moving
	z.NoPowerCheck = 1   --use this to disable the power checking in this function
	z.EvenIfNotUsable = 1   --use this to disable the usability checking in this function and may be used if currently in the process of completing a prerequisite that will make the spell usable
	z.GlobalVehicleCooldownSpell = GlobalSpellID--[[English_Spell_Name]]   -- use this if spell has more than a global cooldown
	z.Unit = "target"   --this should not be used unless the spell is not to be cast on the target
	z.Interrupt = 1   --use this if the target should be casting or channeling an interruptible ability
	return s.CheckIfVehicleSpellCastable(z)
end



AddonTable.Castable["Auto Attack"] = function()
	wipe(z)
	z.SpellID = 6603--[[Auto Attack]]
	z.EnemyTargetNeeded = 1
	z.NotIfActive = 1
	return s.MeleeDistance() and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Shoot"] = function()
	wipe(z)
	z.SpellID = 3018--[[Shoot]]
	z.EnemyTargetNeeded = 1
	z.NotIfActive = 1
	return not s.Shooting() and s.CheckIfSpellCastable(z)
end

local function OtherAurasFunction()
	if s.HasTalent(17793--[[Shadow and Flame]]) then
		s.SetOtherAuras(686--[[Shadow Bolt]], 17800--[[Shadow and Flame]])
		s.SetOtherAuras(29722--[[Incinerate]], 17800--[[Shadow and Flame]])
	end
	if s.HasTalent(32385--[[Shadow Embrace]]) then
		s.SetOtherAuras(686--[[Shadow Bolt]], 32385--[[Shadow Embrace]])
		s.SetOtherAuras(48181--[[Haunt]], 32385--[[Shadow Embrace]])
	end
	if s.HasTalent(18179--[[Jinx]]) then
		s.SetOtherAuras(1490--[[Curse of the Elements]], 85547--[[Jinx: Curse of the Elements]])
	end
end
s.RegisterOtherAurasFunction(OtherAurasFunction)

local function OnEvent(self, event, ...)
	if event == "COMBAT_LOG_EVENT_UNFILTERED" then
		local Event, sourceGUID, GUID, SpellName
		if Build >= 40200 then
			Event = select(2, ...)
			sourceGUID = select(4, ...)
			GUID = select(8, ...)
			SpellName = select(13, ...)
		elseif Build >= 40100 then
			Event = select(2, ...)
			sourceGUID = select(4, ...)
			GUID = select(7, ...)
			SpellName = select(11, ...)
		else
			Event = select(2, ...)
			sourceGUID = select(3, ...)
			GUID = select(6, ...)
			SpellName = select(10, ...)
		end
		if Event == "SPELL_CAST_SUCCESS" and sourceGUID == UnitGUID("player") and SpellName == s.SpellName(86121--[[Soul Swap]], 1) then
			AddonTable.LastSoulSwap = GUID
		end
	end
end
local EventFrame = CreateFrame("Frame")
EventFrame:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
EventFrame:SetScript("OnEvent", OnEvent)


local Curses = {
	1490--[[Curse of the Elements]],
	1714--[[Curse of Tongues]],
	702--[[Curse of Weakness]],
	18223--[[Curse of Exhaustion]],
}

local JinxCurses = {
	85547--[[Jinx: Curse of the Elements]],
	1714--[[Curse of Tongues]],
	702--[[Curse of Weakness]],
	18223--[[Curse of Exhaustion]],
}

local Banes = {
	980--[[Bane of Agony]],
	603--[[Bane of Doom]],
	80240--[[Bane of Havoc]],
}

function AddonTable.CursePushed(unit)
	if s.HasTalent(18179--[[Jinx]]) then
		return s.SpellOrAuraDelay(JinxCurses, unit) or s.CurrentSpell(Curses)
	end
	return s.SpellOrAuraDelay(Curses, unit) or s.CurrentSpell(Curses)
end

function AddonTable.BanePushed(unit)
	return s.SpellOrAuraDelay(Banes, unit) or s.CurrentSpell(Banes)
end


AddonTable.ItemCastable["Healthstone"] = function()
	wipe(z)
	z.ItemName = 5512--[[Healthstone]]
	return ( x.ActiveEnemy or s.InCombat() ) and s.HealthPercent("player") <= 35 and s.CheckIfItemCastable(z)
end

AddonTable.ItemCastable["Soulstone"] = function()
	wipe(z)
	z.ItemName = 5232--[[Soulstone]]
	z.CastTime = s.CastTime(20707--[[Soulstone Resurrection]])
	z.NoRangeCheck = 1
	z.NotIfActive = 1
	--z.NotWhileMoving = 1
	if x.ShouldTemporaryBuff and s.CheckIfItemCastable(z) then
		if x.InstanceType == "arena" then
			return not s.Buff(20707--[[Soulstone Resurrection]], "raid|range", z.CastTime + x.DoubleLag + 20)
		elseif x.InstanceType ~= "pvp" and ( GetNumRaidMembers() > 1 or GetNumPartyMembers() > 0 ) and s.Healer("raid|afk|notself") then
			return not s.Buff(20707--[[Soulstone Resurrection]], "raid|healer|afk|notself", z.CastTime + x.DoubleLag + 20)
		end
		return not s.Buff(20707--[[Soulstone Resurrection]], "player", z.CastTime + x.DoubleLag + 20)
	end
	return false
end

AddonTable.Castable["Metamorphosis"] = function()
	wipe(z)
	z.SpellID = 47241--[[Metamorphosis]]
	z.EnemyTargetNeeded = 1
	return x.ShouldTemporaryBuff and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Demon Leap"] = function()
	wipe(z)
	z.SpellID = 54785--[[Demon Leap]]
	z.EnemyTargetNeeded = 1
	return not CheckInteractDistance(s.UnitSelection(), 3) and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Immolation Aura"] = function()
	wipe(z)
	z.SpellID = 50589--[[Immolation Aura]]
	return s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Shadow Ward"] = function()
	wipe(z)
	z.SpellID = 6229--[[Shadow Ward]]
	z.EnemyTargetNeeded = 1
	return x.ShouldTemporaryBuff and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Summon Imp"] = function()
	wipe(z)
	z.SpellID = 688--[[Summon Imp]]
	--z.NotWhileMoving = not s.Buff(74434--[[Soulburn]], "player")
	return not x.PetAlive and x.ShouldPermanentBuff and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Summon Succubus"] = function()
	wipe(z)
	z.SpellID = 712--[[Summon Succubus]]
	--z.NotWhileMoving = not s.Buff(74434--[[Soulburn]], "player")
	return not x.PetAlive and x.ShouldPermanentBuff and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Summon Voidwalker"] = function()
	wipe(z)
	z.SpellID = 697--[[Summon Voidwalker]]
	--z.NotWhileMoving = not s.Buff(74434--[[Soulburn]], "player")
	return not x.PetAlive and x.ShouldPermanentBuff and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Summon Felhunter"] = function()
	wipe(z)
	z.SpellID = 691--[[Summon Felhunter]]
	--z.NotWhileMoving = not s.Buff(74434--[[Soulburn]], "player")
	return not x.PetAlive and x.ShouldPermanentBuff and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Summon Felguard"] = function()
	wipe(z)
	z.SpellID = 30146--[[Summon Felguard]]
	--z.NotWhileMoving = not s.Buff(74434--[[Soulburn]], "player")
	return not x.PetAlive and x.ShouldPermanentBuff and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Soul Link"] = function()
	wipe(z)
	z.SpellID = 19028--[[Soul Link]]
	z.Buff = z.SpellID
	z.BuffUnit = "pet"
	z.NoRangeCheck = 1
	return x.PetAlive and x.ShouldPermanentBuff and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Demonic Empowerment"] = function()
	wipe(z)
	z.SpellID = 47193--[[Demonic Empowerment]]
	return s.NotDieing("pettarget") and not s.Debuff(1098--[[Enslave Demon]], "pet") and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Demon Soul"] = function()
	wipe(z)
	z.SpellID = 77801--[[Demon Soul]]
	z.EnemyTargetNeeded = 1
	return x.PetAlive and not s.Debuff(1098--[[Enslave Demon]], "pet") and s.NotDieing() and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Summon Doomguard"] = function()
	wipe(z)
	z.SpellID = 18540--[[Summon Doomguard]]
	z.EnemyTargetNeeded = 1
	return ( s.Player() or s.Boss() ) and s.MyDebuff(Banes) and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Summon Infernal"] = function()
	wipe(z)
	z.SpellID = 1122--[[Summon Infernal]]
	z.EnemyTargetNeeded = 1
	z.NoRangeCheck = 1
	z.NotWhileMoving = 1
	return ( s.Player() or s.Boss() ) and s.MyDebuff(Banes) and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Bane of Agony"] = function()
	wipe(z)
	z.SpellID = 980--[[Bane of Agony]]
	z.DebuffSlotNeeded = 1
	z.MyDebuff = Banes
	z.EnemyTargetNeeded = 1
	return ( not s.Buff(86121--[[Soul Swap]], "player") or s.HasGlyph(57270--[[Glyph of Soul Swap]]) ) and not AddonTable.BanePushed() and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Bane of Doom"] = function()
	wipe(z)
	z.SpellID = 603--[[Bane of Doom]]
	z.DebuffSlotNeeded = 1
	z.MyDebuff = Banes
	z.EnemyTargetNeeded = 1
	return ( not s.Buff(86121--[[Soul Swap]], "player") or s.HasGlyph(57270--[[Glyph of Soul Swap]]) ) and s.HealthPercent() > 25 and s.Boss() and not AddonTable.BanePushed() and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Bane of Havoc"] = function()
	wipe(z)
	z.SpellID = 80240--[[Bane of Havoc]]
	z.DebuffSlotNeeded = 1
	z.MyDebuff = Banes
	z.EnemyTargetNeeded = 1
	return not AddonTable.BanePushed() and s.CheckIfSpellCastable(z)
end

local CurseoftheElementsDebuff = {
	1490--[[Curse of the Elements]],
	85547--[[Jinx: Curse of the Elements]],
}
local CurseoftheElementsMyDebuff = {
	702--[[Curse of Weakness]],
	1714--[[Curse of Tongues]],
	18223--[[Curse of Exhaustion]],
}
AddonTable.Castable["Curse of the Elements"] = function()
	wipe(z)
	z.SpellID = 1490--[[Curse of the Elements]]
	z.Debuff = CurseoftheElementsDebuff
	z.MyDebuff = CurseoftheElementsMyDebuff
	z.EarlyRefresh = 10
	z.EnemyTargetNeeded = 1
	return not AddonTable.CursePushed() and s.CheckIfSpellCastable(z)
end

local CurseofTonguesMyDebuff = {
	85547--[[Jinx: Curse of the Elements]],
	1490--[[Curse of the Elements]],
	702--[[Curse of Weakness]],
	18223--[[Curse of Exhaustion]],
}
AddonTable.Castable["Curse of Tongues"] = function()
	wipe(z)
	z.SpellID = 1714--[[Curse of Tongues]]
	z.Debuff = z.SpellID
	z.MyDebuff = CurseofTonguesMyDebuff
	z.EnemyTargetNeeded = 1
	return not AddonTable.CursePushed() and s.CheckIfSpellCastable(z)
end

local CurseofWeaknessDebuff = {
	702--[[Curse of Weakness]],
	1160--[[Demoralizing Shout]],
	99--[[Demoralizing Roar]],
	24423--[[Demoralizing Screech]],
	26016--[[Vindication]],
}
local CurseofWeaknessMyDebuff = {
	85547--[[Jinx: Curse of the Elements]],
	1490--[[Curse of the Elements]],
	1714--[[Curse of Tongues]],
	18223--[[Curse of Exhaustion]],
}
AddonTable.Castable["Curse of Weakness"] = function()
	wipe(z)
	z.SpellID = 702--[[Curse of Weakness]]
	z.Debuff = CurseofWeaknessDebuff
	z.MyDebuff = CurseofWeaknessMyDebuff
	z.EarlyRefresh = 5
	z.EnemyTargetNeeded = 1
	return not AddonTable.CursePushed() and s.CheckIfSpellCastable(z)
end

local CurseofExhaustionMyDebuff = {
	85547--[[Jinx: Curse of the Elements]],
	1490--[[Curse of the Elements]],
	702--[[Curse of Weakness]],
	1714--[[Curse of Tongues]],
}
AddonTable.Castable["Curse of Exhaustion"] = function()
	wipe(z)
	z.SpellID = 18223--[[Curse of Exhaustion]]
	z.Debuff = z.SpellID
	z.MyDebuff = CurseofExhaustionMyDebuff
	z.EnemyTargetNeeded = 1
	return s.Player() and not AddonTable.CursePushed() and s.CheckIfSpellCastable(z)
end

local ImmolateAndUnstableAffliction = {
	348--[[Immolate]],
	30108--[[Unstable Affliction]],
}
AddonTable.Castable["Immolate"] = function()
	wipe(z)
	z.SpellID = 348--[[Immolate]]
	z.DebuffSlotNeeded = 1
	z.MyDebuff = ImmolateAndUnstableAffliction
	z.EnemyTargetNeeded = 1
	z.NotWhileMoving = 1
	if s.HasTalent(85103--[[Cremation]]) then
		local casting = s.Casting(71521--[[Hand of Gul'dan]], "player")
		if ( casting and s.MyDebuff(z.SpellID, nil, casting + x.DoubleLag) ) or ( s.SpellDelay(71521--[[Hand of Gul'dan]]) and s.MyDebuff(z.SpellID, nil, x.DoubleLag) ) then
			return false
		end
	end
	return ( not s.Buff(86121--[[Soul Swap]], "player") or s.HasGlyph(57270--[[Glyph of Soul Swap]]) ) and not s.SpellOrAuraDelay(30108--[[Unstable Affliction]]) and not s.CurrentSpell(30108--[[Unstable Affliction]]) and not s.Casting(30108--[[Unstable Affliction]], "player") and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Unstable Affliction"] = function()
	wipe(z)
	z.SpellID = 30108--[[Unstable Affliction]]
	z.DebuffSlotNeeded = 1
	z.MyDebuff = ImmolateAndUnstableAffliction
	z.EnemyTargetNeeded = 1
	z.NotWhileMoving = 1
	return ( not s.Buff(86121--[[Soul Swap]], "player") or s.HasGlyph(57270--[[Glyph of Soul Swap]]) ) and not s.SpellOrAuraDelay(348--[[Immolate]]) and not s.CurrentSpell(348--[[Immolate]]) and not s.Casting(348--[[Immolate]], "player") and s.CheckIfSpellCastable(z)
end

local CorruptionAndSeedofCorruption = {
	172--[[Corruption]],
	27243--[[Seed of Corruption]],
}
AddonTable.Castable["Corruption"] = function()
	wipe(z)
	z.SpellID = 172--[[Corruption]]
	z.DebuffSlotNeeded = 1
	z.MyDebuff = CorruptionAndSeedofCorruption
	z.EnemyTargetNeeded = 1
	return ( not s.Buff(86121--[[Soul Swap]], "player") or s.HasGlyph(57270--[[Glyph of Soul Swap]]) ) and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Seed of Corruption"] = function()
	wipe(z)
	z.SpellID = 27243--[[Seed of Corruption]]
	z.MyDebuff = CorruptionAndSeedofCorruption
	z.EnemyTargetNeeded = 1
	z.NotWhileMoving = 1
	return ( not s.Buff(86121--[[Soul Swap]], "player") or s.HasGlyph(57270--[[Glyph of Soul Swap]]) ) and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Create Healthstone"] = function()
	wipe(z)
	z.SpellID = 6201--[[Create Healthstone]]
	z.NotIfActive = 1
	--z.NotWhileMoving = 1
	return x.ShouldTemporaryBuff and GetItemCount(5512--[[Healthstone]], true) == 0 and not s.CastingOrChanneling(29893--[[Ritual of Souls]], "player") and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Ritual of Souls"] = function()
	wipe(z)
	z.SpellID = 29893--[[Ritual of Souls]]
	z.NoRangeCheck = 1
	z.NotIfActive = 1
	--z.NotWhileMoving = 1
	return x.ShouldTemporaryBuff and ( GetNumRaidMembers() > 2 or GetNumPartyMembers() > 1 ) and GetItemCount(5512--[[Healthstone]], true) == 0 and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Dark Intent"] = function()
	wipe(z)
	z.SpellID = 80398--[[Dark Intent]]
	z.MyBuff = z.SpellID
	z.BuffUnit = "player"
	z.NoRangeCheck = 1
	return x.ShouldTemporaryBuff and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Death Coil"] = function()
	wipe(z)
	z.SpellID = 6789--[[Death Coil]]
	z.EnemyTargetNeeded = 1
	return s.CheckIfSpellCastable(z)
end

local DemonArmorAndFelArmor = {
	687--[[Demon Armor]],
	28176--[[Fel Armor]],
}
AddonTable.Castable["Demon Armor"] = function()
	wipe(z)
	z.SpellID = 687--[[Demon Armor]]
	z.Buff = DemonArmorAndFelArmor
	z.BuffUnit = "player"
	return x.ShouldPermanentBuff and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Fel Armor"] = function()
	wipe(z)
	z.SpellID = 28176--[[Fel Armor]]
	z.Buff = DemonArmorAndFelArmor
	z.BuffUnit = "player"
	return x.ShouldPermanentBuff and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Demonic Circle: Teleport"] = function()
	wipe(z)
	z.SpellID = 48020--[[Demonic Circle: Teleport]]
	return s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Demonic Circle: Summon"] = function()
	wipe(z)
	z.SpellID = 48018--[[Demonic Circle: Summon]]
	z.NotWhileMoving = 1
	return s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Drain Life"] = function()
	wipe(z)
	z.SpellID = 689--[[Drain Life]]
	z.EnemyTargetNeeded = 1
	z.NotWhileMoving = 1
	return s.HealthPercent("player") <= 70 and ( not s.MeleeDistance("focus") or not s.EnemyTargetingYou("focus") ) and ( not s.MeleeDistance("enemy") or not s.EnemyTargetingYou("enemy") ) and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Drain Mana"] = function()
	wipe(z)
	z.SpellID = 5138--[[Drain Mana]]
	z.EnemyTargetNeeded = 1
	z.TargetThatUsesManaNeeded = 1
	z.NotWhileMoving = 1
	return s.HasMana() and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Drain Soul"] = function()
	wipe(z)
	z.SpellID = 1120--[[Drain Soul]]
	z.EnemyTargetNeeded = 1
	z.NotWhileMoving = 1
	return s.HealthPercent() <= 25 and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Health Funnel"] = function()
	wipe(z)
	z.SpellID = 755--[[Health Funnel]]
	z.NoRangeCheck = 1
	z.NotIfActive = 1
	--z.NotWhileMoving = 1
	return x.PetAlive and s.HealthPercent("pet") <= 90 and s.HealthPercent("player") >= 10 and not s.CastingOrChanneling(17767--[[Consume Shadows]], "pet") and ( not s.InCombat() or s.HealthPercent("pet") <= 70 ) and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Incinerate"] = function()
	wipe(z)
	z.SpellID = 29722--[[Incinerate]]
	z.EnemyTargetNeeded = 1
	z.NotWhileMoving = 1
	return s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Life Tap"] = function()
	if not x.ShouldPermanentBuff or s.PowerPercent("player") >= 75 then
		return false
	elseif x.EnemyDetected or not s.HasSpell(79268--[[Soul Harvest]]) or s.SpellCooldown(79268--[[Soul Harvest]]) > s.SpellCooldown(1454--[[Life Tap]]) then
		if ( s.InCombat() and ( s.EnemyTargetingYou("focus") or s.EnemyTargetingYou("enemy") ) )
		or not ( ( s.PowerPercent("player") >= 75 and s.HealthPercent("player") >= 98 ) or ( s.PowerPercent("player") < 75 and s.HealthPercent("player") >= 95 ) ) then
			return false
		end
	elseif s.HealthPercent("player") < 30 then
		return false
	end
	wipe(z)
	z.SpellID = 1454--[[Life Tap]]
	return s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Searing Pain"] = function()
	wipe(z)
	z.SpellID = 5676--[[Searing Pain]]
	z.EnemyTargetNeeded = 1
	z.NotWhileMoving = 1
	return s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Shadow Bolt"] = function()
	wipe(z)
	z.SpellID = 686--[[Shadow Bolt]]
	z.EnemyTargetNeeded = 1
	z.NotWhileMoving = not s.Buff(17941--[[Shadow Trance]], "player")
	return s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Shadowflame"] = function()
	wipe(z)
	z.SpellID = 47897--[[Shadowflame]]
	z.EnemyTargetNeeded = 1
	return ( not s.Buff(86121--[[Soul Swap]], "player") or s.HasGlyph(57270--[[Glyph of Soul Swap]]) ) and CheckInteractDistance(s.UnitSelection(), 3) and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Soul Fire"] = function(Buff)
	wipe(z)
	z.SpellID = 6353--[[Soul Fire]]
	z.Buff = Buff
	z.BuffUnit = "player"
	z.EnemyTargetNeeded = 1
	z.NotWhileMoving = not s.Buff(74434--[[Soulburn]], "player")
	return s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Soul Harvest"] = function()
	wipe(z)
	z.SpellID = 79268--[[Soul Harvest]]
	--z.NotWhileMoving = 1
	return x.ShouldPermanentBuff and ( s.HealthPercent("player") <= 80 or s.PowerPercent("player", SPELL_POWER_SOUL_SHARDS) < 100 ) and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Soulburn"] = function()
	wipe(z)
	z.SpellID = 74434--[[Soulburn]]
	return s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Soulshatter"] = function()
	wipe(z)
	z.SpellID = 29858--[[Soulshatter]]
	z.EnemyTargetNeeded = 1
	return x.ThreatPercent >= 90 and not UnitPlayerControlled(s.UnitSelection()) and s.SpellInRange(686--[[Shadow Bolt]]) and ( GetNumRaidMembers() > 1 or GetNumPartyMembers() > 0 or ( s.SameTargetAsPet() and ( s.HasSpell(3716--[[Torment]]) or s.HasSpell(30213--[[Legion Strike]]) ) ) ) and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Conflagrate"] = function()
	wipe(z)
	z.SpellID = 17962--[[Conflagrate]]
	z.EvenIfNotUsable = s.SpellOrAuraDelay(348--[[Immolate]]) or s.CurrentSpell(348--[[Immolate]]) or s.Casting(348--[[Immolate]], "player") or s.MyDebuff(348--[[Immolate]])
	return z.EvenIfNotUsable and s.CheckIfSpellCastable(z)
end

local UnendingBreath = {
	5697--[[Unending Breath]],
	73701--[[Sea Legs]],
}
AddonTable.Castable["Unending Breath"] = function()
	wipe(z)
	z.SpellID = 5697--[[Unending Breath]]
	z.Buff = UnendingBreath
	z.BuffUnit = "player"
	z.NoRangeCheck = 1
	return ( GetMirrorTimerProgress("BREATH") > 0 or ( x.ShouldPermanentBuff and IsSwimming() and s.HasGlyph(58336--[[Glyph of Unending Breath]]) ) ) and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Create Soulstone"] = function()
	wipe(z)
	z.SpellID = 693--[[Create Soulstone]]
	z.NotIfActive = 1
	--z.NotWhileMoving = 1
	return x.ShouldTemporaryBuff and GetItemCount(5232--[[Soulstone]], true) == 0 and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Chaos Bolt"] = function()
	wipe(z)
	z.SpellID = 50796--[[Chaos Bolt]]
	z.EnemyTargetNeeded = 1
	z.NotWhileMoving = 1
	return s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Haunt"] = function()
	wipe(z)
	z.SpellID = 48181--[[Haunt]]
	z.EnemyTargetNeeded = 1
	z.NotIfActive = 1
	z.NotWhileMoving = 1
	return s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Shadowburn"] = function()
	wipe(z)
	z.SpellID = 17877--[[Shadowburn]]
	z.EnemyTargetNeeded = 1
	return s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Fel Flame"] = function()
	wipe(z)
	z.SpellID = 77799--[[Fel Flame]]
	z.EnemyTargetNeeded = 1
	return s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Shadowfury"] = function()
	wipe(z)
	z.SpellID = 30283--[[Shadowfury]]
	z.EnemyTargetNeeded = 1
	z.NoRangeCheck = 1
	return s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Hand of Gul'dan"] = function()
	wipe(z)
	z.SpellID = 71521--[[Hand of Gul'dan]]
	z.EnemyTargetNeeded = 1
	z.NotIfActive = 1
	z.NotWhileMoving = 1
	return UnitExists("pettarget") and s.CheckIfSpellCastable(z)
end

local Debuffs = {
	980--[[Bane of Agony]],
	603--[[Bane of Doom]],
	348--[[Immolate]],
	30108--[[Unstable Affliction]],
	172--[[Corruption]],
	27243--[[Seed of Corruption]],
	47897--[[Shadowflame]],
}
AddonTable.Castable["Soul Swap"] = function()
	wipe(z)
	z.SpellID = 86121--[[Soul Swap]]
	z.EnemyTargetNeeded = 1
	return not s.Buff(86121--[[Soul Swap]], "player") and s.HealthPercent() <= 25 and not s.Boss() and s.CheckIfSpellCastable(z) and s.MyDebuff(Debuffs)
end

AddonTable.Castable["Soul Swap Exhale"] = function()
	wipe(z)
	z.SpellID = 86121--[[Soul Swap]]
	z.EvenIfNotUsable = 1
	z.NoPowerCheck = 1
	z.EnemyTargetNeeded = 1
	return s.Buff(86121--[[Soul Swap]], "player") and UnitGUID(s.UnitSelection()) ~= AddonTable.LastSoulSwap and s.CheckIfSpellCastable(z)
end

AddonTable.Castable["Banish"] = function(unit)
	wipe(z)
	z.SpellID = 710--[[Banish]]
	z.Unit = unit
	--z.NotWhileMoving = 1
	z.EnemyTargetNeeded = 1
	local seconds = s.CastTime(z.SpellID) + s.SpellCooldown(z.SpellID) + x.DoubleLag
	return not s.Boss(z.Unit) and s.CheckIfSpellCastable(z) and not s.ImmunityDebuff(z.Unit, seconds) and not s.BreakOnDamageCC(z.Unit, seconds + 5)
end

